@@ -1,6 +1,7 @@
 package bulk
 
 import (
+	"context"
 	"encoding/json"
 	"fmt"
 	"io"
@@ -11,8 +12,6 @@ import (
 	"strings"
 
 	"github.com/danielgtaylor/mexpr"
-	"github.com/danielgtaylor/restish/cli"
-	"github.com/danielgtaylor/restish/openapi"
 	"github.com/danielgtaylor/shorthand/v2"
 	"github.com/hexops/gotextdiff"
 	"github.com/hexops/gotextdiff/myers"
@@ -21,6 +20,8 @@ import (
 	"github.com/pb33f/libopenapi/datamodel/low"
 	lowbase "github.com/pb33f/libopenapi/datamodel/low/base"
 	"github.com/pb33f/libopenapi/index"
+	"github.com/rest-sh/restish/cli"
+	"github.com/rest-sh/restish/openapi"
 	"github.com/spf13/afero"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
@@ -85,7 +86,7 @@ func newInterpreter(expression, schemaURL string) mexpr.Interpreter {
 
 				if err := yaml.Unmarshal(body, &rootNode); err == nil {
 					if err := low.BuildModel(rootNode.Content[0], &ls); err == nil {
-						if err := ls.Build(rootNode.Content[0], index.NewSpecIndex(&rootNode)); err == nil {
+						if err := ls.Build(context.TODO(), rootNode.Content[0], index.NewSpecIndex(&rootNode)); err == nil {
 							s := base.NewSchema(&ls)
 							result := openapi.GenExample(s, 0)
 							if asMap, ok := result.(map[string]any); ok {
@@ -100,7 +101,7 @@ func newInterpreter(expression, schemaURL string) mexpr.Interpreter {
 
 	ast, err := mexpr.Parse(expression, example, mexpr.UnquotedStrings)
 	if err != nil {
-		cli.LogWarning(err.Pretty(expression))
+		cli.LogWarning("%s", err.Pretty(expression))
 		// Just return a falsey value to filter these files out.
 		ast = &mexpr.Node{
 			Type:  mexpr.NodeLiteral,
